/*
 * Copyright 2007-2009 Florian Köberle
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.delphigl.files.zip;

import java.io.File;
import java.io.FileFilter;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

public class DirectoryZipper {
	private final FileFilter fileFilterStrategy;

	public DirectoryZipper(FileFilter strategy) {
		this.fileFilterStrategy = strategy;
	}

	public void zipDirectory(File contentDirectory, File zipFile)
			throws IOException {
		try {
			final FileOutputStream outputStream = new FileOutputStream(zipFile);
			try {
				final ZipOutputStream zipOutputStream = new ZipOutputStream(
						outputStream);
				zipDirectoryToStream(zipOutputStream, contentDirectory, "");
				zipOutputStream.close();
			} finally {
				outputStream.close();
			}
		} catch (IOException e) {
			IOException exception = new IOException(
					"IOException while zipping: " + contentDirectory.getName());
			exception.initCause(e);
			throw exception;
		}
	}

	private void zipDirectoryToStream(ZipOutputStream zipOutputStream,
			File directory, String prefix) throws IOException {
		byte[] buffer = new byte[1024];
		for (File file : directory.listFiles(fileFilterStrategy)) {
			if (file.isFile()) {
				final String zipEntryName = prefix + file.getName();
				final ZipEntry entry = new ZipEntry(zipEntryName);
				zipOutputStream.putNextEntry(entry);
				final InputStream inputStream = new FileInputStream(file);
				try {
					while (true) {
						final int readedBytes = inputStream.read(buffer);
						if (readedBytes == -1)
							break;
						zipOutputStream.write(buffer, 0, readedBytes);
					}
				} finally {
					inputStream.close();
				}
			} else if (file.isDirectory()) {
				final String newPrefix = prefix + file.getName()
						+ File.separator;
				zipDirectoryToStream(zipOutputStream, file, newPrefix);
			}
		}
	}
}
