/*
 * Copyright 2007-2009 Florian Köberle
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.delphigl.files.hashcalculation;

import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

public class SimpleHashCalculator {

	public byte[] calculateHash(InputStream inputStream) throws IOException {
		final MessageDigest messageDigest = createMessageDigest();

		// the bufferedInputStream can not be closed because the inner
		// inputStream should not be closed
		final BufferedInputStream bufferedInputStream = new BufferedInputStream(
				inputStream);
		byte[] buffer = new byte[1024];
		while (true) {
			int readedBytes = bufferedInputStream.read(buffer);
			if (readedBytes == -1) {
				break;
			}
			messageDigest.update(buffer, 0, readedBytes);
		}

		return messageDigest.digest();
	}

	/**
	 * @return a tool for calculating the checksum.
	 */
	public static MessageDigest createMessageDigest() {
		final MessageDigest checksum;
		try {
			checksum = MessageDigest.getInstance("SHA-1");
		} catch (NoSuchAlgorithmException e) {
			throw new RuntimeException(e);
		}
		return checksum;
	}

}
