/*
 * Copyright 2007-2009 Florian Köberle
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.delphigl.files.hashcalculation;

import java.io.IOException;
import java.io.InputStream;
import java.security.MessageDigest;
import java.util.Map;
import java.util.SortedMap;
import java.util.TreeMap;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;

public class ZipFileHashCalculator {
	private final MasterHashCalculator masterHashCalculator;

	public ZipFileHashCalculator(MasterHashCalculator masterHashCalculator) {
		this.masterHashCalculator = masterHashCalculator;
	}

	public byte[] calculateHash(InputStream inputStream) throws IOException {
		final ZipInputStream zipInputStream = new ZipInputStream(inputStream);

		final SortedMap<String, byte[]> nameHashMap = getHashedEntriesInSortedMap(zipInputStream);
		final MessageDigest messageDigest = SimpleHashCalculator
				.createMessageDigest();
		// loop over the sorted entries
		for (Map.Entry<String, byte[]> entry : nameHashMap.entrySet()) {
			messageDigest.update(entry.getKey().getBytes());
			messageDigest.update(entry.getValue());
		}
		return messageDigest.digest();
	}

	private SortedMap<String, byte[]> getHashedEntriesInSortedMap(
			ZipInputStream zipInputStream) throws IOException {
		SortedMap<String, byte[]> nameHashMap = new TreeMap<String, byte[]>();
		while (true) {
			final ZipEntry zipEntry = zipInputStream.getNextEntry();
			if (zipEntry == null) {
				break;
			}
			final String name = zipEntry.getName();
			final byte[] hash = masterHashCalculator.calculateHash(name,
					zipInputStream);
			zipInputStream.closeEntry();
			final String generalName = name.replace("\\", "/");
			nameHashMap.put(generalName, hash);
		}
		return nameHashMap;
	}

}
