/*
 * Copyright 2007-2009 Florian Köberle
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.delphigl.files.uploader.controller;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import javax.xml.bind.Unmarshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

@XmlRootElement(name = "configuration")
@XmlAccessorType(XmlAccessType.NONE)
@XmlType(name = "configurationType", propOrder = { "ftp", "sourceDirectory" })
public class Configuration {
	private String sourceDirectory;
	private FTPConfiguration ftp;

	public Configuration() {
		ftp = new FTPConfiguration();
	}

	public static Configuration readConfigurationFile(File file)
			throws JAXBException {
		final JAXBContext context = JAXBContext
				.newInstance(Configuration.class);
		final Unmarshaller unmarshaller = context.createUnmarshaller();
		return (Configuration) unmarshaller.unmarshal(file);
	}

	public void save(File file) throws JAXBException, IOException {
		final JAXBContext context = JAXBContext
				.newInstance(Configuration.class);
		final Marshaller marshaller = context.createMarshaller();
		marshaller.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.TRUE);
		marshaller.marshal(this, new FileWriter(file));
	}

	@XmlElement(name = "ftp")
	public FTPConfiguration getFtp() {
		return this.ftp;
	}

	public void setFtp(FTPConfiguration ftp) {
		this.ftp = ftp;
	}

	@XmlElement(required = false)
	public String getSourceDirectory() {
		return this.sourceDirectory;
	}

	public void setSourceDirectory(String sourceDirectory) {
		this.sourceDirectory = sourceDirectory;
	}

	public String getFTPHost() {
		return this.ftp.getHost();
	}

	public String getFTPPassword() {
		return this.ftp.getPassword();
	}

	public String getFTPTargetDirectory() {
		return this.ftp.getTargetDirectory();
	}

	public String getFTPUsername() {
		return this.ftp.getUsername();
	}

	public void setFTPHost(String host) {
		this.ftp.setHost(host);
	}

	public void setFTPPassword(String password) {
		this.ftp.setPassword(password);
	}

	public void setFTPTargetDirectory(String targetDirectory) {
		this.ftp.setTargetDirectory(targetDirectory);
	}

	public void setFTPUsername(String username) {
		this.ftp.setUsername(username);
	}

}
