/*
 * Copyright 2007-2009 Florian Köberle
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.delphigl.files.uploader.model.generation;

import java.io.File;
import java.io.FileFilter;
import java.io.IOException;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Set;

import com.delphigl.files.zip.DirectoryZipper;

public class ArchiveGenerator {
	private final List<File> directoriesToArchive;
	private final Set<ArchiveGenerationListener> listenerSet;
	private final File targetDirectory;
	private final FileFilter fileFilter;

	public ArchiveGenerator(File sourceDirectory, File targetDirectory) {
		this.targetDirectory = targetDirectory;
		this.listenerSet = new HashSet<ArchiveGenerationListener>();
		this.fileFilter = new FileFilter() {
			@Override
			public boolean accept(File pathname) {
				return !".svn".equals(pathname.getName());
			}
		};
		this.directoriesToArchive = new LinkedList<File>();

		for (final File directory : sourceDirectory.listFiles(fileFilter)) {
			if (directory.isDirectory()) {
				directoriesToArchive.add(directory);
			}
		}

	}

	public void generate() throws IOException {
		final DirectoryZipper directoryZipper = new DirectoryZipper(fileFilter);
		for (File directory : directoriesToArchive) {
			final File zipFile = new File(targetDirectory, directory.getName()
					+ ".zip");
			directoryZipper.zipDirectory(directory, zipFile);
			for (ArchiveGenerationListener listener : listenerSet) {
				listener.archiveGenerated(zipFile);
			}
		}
	}

	/**
	 * @return
	 */
	public int getNumberOfPlannedResults() {
		return directoriesToArchive.size();
	}

	public boolean addListener(ArchiveGenerationListener e) {
		return this.listenerSet.add(e);
	}

}
