/*
 * Copyright 2007-2009 Florian Köberle
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.delphigl.files.uploader.view;

import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JPanel;

import com.delphigl.files.uploader.controller.Controller;
import com.delphigl.files.uploader.controller.OperationPossibilityListener;

class ButtonPanel extends JPanel {
	private static final long serialVersionUID = -9011338970199708843L;
	private final Controller controller;
	private final JButton validateButton;
	private final JButton saveButton;
	private final JButton generateButton;
	private final JButton openTargetFolderButton;
	private final JButton simulateUploadButton;
	private final JButton uploadChangesButton;
	private final JButton openLogFileButton;

	public ButtonPanel(final Controller controller) {
		this.controller = controller;
		this.validateButton = new JButton("validate configuration");
		this.saveButton = new JButton("save configuration");
		this.generateButton = new JButton("generate zip files");
		this.openTargetFolderButton = new JButton("open target folder");
		this.simulateUploadButton = new JButton("simulate upload");
		this.uploadChangesButton = new JButton("upload changes");
		this.openLogFileButton = new JButton("open log file");

		updateButtons();
		controller
				.addOperationPossibilityListener(new OperationPossibilityListener() {
					@Override
					public void handleOperationPossibilityChange() {
						updateButtons();
					}
				});

		setLayout(new GridLayout(0, 1));
		add(validateButton);
		add(saveButton);
		add(generateButton);
		add(openTargetFolderButton);
		add(simulateUploadButton);
		add(uploadChangesButton);
		add(openLogFileButton);

		validateButton.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				controller.validate();
			}
		});
		saveButton.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				controller.save();
			}
		});
		generateButton.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				controller.generate();
			}
		});
		openTargetFolderButton.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				controller.openTargetFolder();
			}
		});
		simulateUploadButton.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				controller.simulateUpload();
			}
		});
		uploadChangesButton.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				controller.uploadChanges();
			}
		});
		openLogFileButton.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				controller.openLogFile();
			}
		});
	}

	private void updateButtons() {
		validateButton.setEnabled(controller.isValidateConfigurationPossible());
		saveButton.setEnabled(controller.isSaveConfigurationPossible());
		generateButton.setEnabled(controller.isGenerateArchivesPossible());
		openTargetFolderButton.setEnabled(controller
				.isOpenTargetFolderPossible());
		simulateUploadButton.setEnabled(controller.isSimulateUploadPossible());
		uploadChangesButton.setEnabled(controller.isUploadChangesPossible());
		openLogFileButton.setEnabled(controller.isOpenLogFilePossible());
	}

}