/*
 * Copyright 2007-2009 Florian Köberle
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.delphigl.files.uploader.view;

import java.awt.BorderLayout;
import java.io.File;
import java.util.List;

import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JScrollPane;
import javax.swing.JTable;

import com.delphigl.files.uploader.controller.ArchiveListGenerationListener;
import com.delphigl.files.uploader.controller.Controller;
import com.delphigl.files.uploader.controller.RemoteUpdateOperation;
import com.delphigl.files.uploader.controller.RemoteUpdateOperationListener;
import com.delphigl.files.uploader.controller.RemoteUpdateProgressListener;

public class ContentPanel extends JPanel {
	private static final long serialVersionUID = 2928761936114918312L;
	private final JProgressBar progressBar;
	private final JTable table;
	private final FileTableModel fileTableModel;
	private final RemoteUpdateSuggestionTableModel remoteUpdateSuggestionTableModel;

	public ContentPanel(Controller controller) {
		this.progressBar = new JProgressBar();
		this.fileTableModel = new FileTableModel();
		this.remoteUpdateSuggestionTableModel = new RemoteUpdateSuggestionTableModel();
		this.table = new JTable(fileTableModel);
		table.setFillsViewportHeight(true);

		progressBar.setMaximum(1);
		progressBar.setValue(1);
		controller
				.addArchiveListGenerationListener(new ArchiveListGenerationListener() {
					@Override
					public void filesGenerated(List<File> files) {
						progressBar.setValue(progressBar.getValue()
								+ files.size());
						if (progressBar.getValue() == progressBar.getMaximum()) {
							progressBar.setString("generated archives");
						}
					}

					@Override
					public void generationStarted(int numberOfPlannedResults) {
						progressBar.setMaximum(numberOfPlannedResults);
						progressBar.setValue(0);
						progressBar.setString("generating archives");
						progressBar.setStringPainted(true);
					}
				});

		controller
				.addArchiveListGenerationListener(new ArchiveListGenerationListener() {
					@Override
					public void filesGenerated(List<File> files) {
						fileTableModel.addFiles(files);
					}

					@Override
					public void generationStarted(int numberOfPlannedResults) {
						fileTableModel.reset();
						table.setModel(fileTableModel);
					}
				});

		controller
				.addRemoteUpdateOperationListener(new RemoteUpdateOperationListener() {

					@Override
					public void newRemoteUpdateOperations(
							List<RemoteUpdateOperation> remoteUpdateOperationsToAdd) {
						remoteUpdateSuggestionTableModel
								.addRemoteUpdateOperationList(remoteUpdateOperationsToAdd);
					}

					@Override
					public void started() {
						remoteUpdateSuggestionTableModel.reset();
						table.setModel(remoteUpdateSuggestionTableModel);
					}

				});

		controller
				.addRemoteUpdateProgressListener(new RemoteUpdateProgressListener() {
					private static final int hugeInt = 1000000;

					@Override
					public void madeProgress(Double progress) {
						progressBar.setValue((int) (hugeInt * progress));
						progressBar.setMaximum(hugeInt);
					}

					@Override
					public void newMessage(String message) {
						progressBar.setString(message);
						progressBar.setStringPainted(true);
					}

				});

		setLayout(new BorderLayout(5, 5));
		add(progressBar, BorderLayout.NORTH);
		add(new JScrollPane(table), BorderLayout.CENTER);
	}

}
