/*
 * Copyright 2007-2009 Florian Köberle
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.delphigl.files.uploader.view;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import javax.swing.table.AbstractTableModel;

class FileTableModel extends AbstractTableModel {
	private static final long serialVersionUID = -2052175072847292034L;
	private final List<File> files = new ArrayList<File>();

	/**
	 * @see javax.swing.table.TableModel#getColumnCount()
	 */
	@Override
	public int getColumnCount() {
		return 1;
	}

	/**
	 * @see javax.swing.table.TableModel#getRowCount()
	 */
	@Override
	public int getRowCount() {
		return files.size();
	}

	/**
	 * @see javax.swing.table.TableModel#getValueAt(int, int)
	 */
	@Override
	public Object getValueAt(int rowIndex, int columnIndex) {
		if (columnIndex == 0) {
			return files.get(rowIndex).getName();
		} else {
			return null;
		}
	}

	@Override
	public String getColumnName(int column) {
		return "generated files";
	}

	public void addFiles(List<File> filesToAdd) {
		final int firstNewRow = files.size();
		files.addAll(filesToAdd);
		fireTableRowsInserted(firstNewRow, files.size() - 1);
	}

	public void reset() {
		files.clear();
		fireTableDataChanged();
	}

}