/*
 * Copyright 2007-2009 Florian Köberle
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.delphigl.files.uploader.view;

import java.util.ArrayList;
import java.util.List;

import javax.swing.table.AbstractTableModel;

import com.delphigl.files.uploader.controller.RemoteUpdateOperation;

class RemoteUpdateSuggestionTableModel extends AbstractTableModel {
	private static final long serialVersionUID = -5293508276008202223L;
	private final List<RemoteUpdateOperation> remoteUpdateViews = new ArrayList<RemoteUpdateOperation>();

	@Override
	public int getColumnCount() {
		return 2;
	}

	@Override
	public int getRowCount() {
		return remoteUpdateViews.size();
	}

	@Override
	public Object getValueAt(int rowIndex, int columnIndex) {
		switch (columnIndex) {
		case 0:
			return remoteUpdateViews.get(rowIndex).getType();
		case 1:
			return remoteUpdateViews.get(rowIndex).getRelativePath();
		default:
			return null;
		}
	}

	@Override
	public String getColumnName(int column) {
		switch (column) {
		case 0:
			return "operation";
		case 1:
			return "file";
		default:
			return null;
		}
	}

	public void addRemoteUpdateOperationList(
			List<RemoteUpdateOperation> remoteUpdateOperationList) {
		final int firstNewRow = remoteUpdateViews.size();
		remoteUpdateViews.addAll(remoteUpdateOperationList);
		fireTableRowsInserted(firstNewRow, remoteUpdateViews.size() - 1);
	}

	public void reset() {
		remoteUpdateViews.clear();
		fireTableDataChanged();
	}

}